@@ -1,13 +1,13 @@
 ## f0-onLoad.R --- 
 ## Author          : Jens Henrik Badsberg, Claus Dethlefsen, Luca La Rocca
 ## Created On      : Mon Mar 14 12:00:00 2005
-## Last Modified By: Luca La Rocca
-## Last Modified On: Fri Feb 17 10:25:00 2006
-## Update Count    : 3
+## Last Modified By: Claus Dethlefsen
+## Last Modified On: Mon Feb 13 13:17:51 2012
+## Update Count    : 4
 ## Status          : Unknown, Use with caution!
 ######################################################
 
 .onLoad <- function(lib, pkg){
-    require(graphics)
-    require(methods)
+#    require(graphics)
+#    require(methods)
 }
